==> lvm2-2.02.66-i586-P1.tgz: install/doinst.sh <==
( cd usr/sbin ; rm -rf lvchange )
( cd usr/sbin ; ln -sf lvm lvchange )
( cd usr/sbin ; rm -rf lvconvert )
( cd usr/sbin ; ln -sf lvm lvconvert )
( cd usr/sbin ; rm -rf lvcreate )
( cd usr/sbin ; ln -sf lvm lvcreate )
( cd usr/sbin ; rm -rf lvdisplay )
( cd usr/sbin ; ln -sf lvm lvdisplay )
( cd usr/sbin ; rm -rf lvextend )
( cd usr/sbin ; ln -sf lvm lvextend )
( cd usr/sbin ; rm -rf lvmchange )
( cd usr/sbin ; ln -sf lvm lvmchange )
( cd usr/sbin ; rm -rf lvmdiskscan )
( cd usr/sbin ; ln -sf lvm lvmdiskscan )
( cd usr/sbin ; rm -rf lvmsadc )
( cd usr/sbin ; ln -sf lvm lvmsadc )
( cd usr/sbin ; rm -rf lvmsar )
( cd usr/sbin ; ln -sf lvm lvmsar )
( cd usr/sbin ; rm -rf lvreduce )
( cd usr/sbin ; ln -sf lvm lvreduce )
( cd usr/sbin ; rm -rf lvremove )
( cd usr/sbin ; ln -sf lvm lvremove )
( cd usr/sbin ; rm -rf lvrename )
( cd usr/sbin ; ln -sf lvm lvrename )
( cd usr/sbin ; rm -rf lvresize )
( cd usr/sbin ; ln -sf lvm lvresize )
( cd usr/sbin ; rm -rf lvs )
( cd usr/sbin ; ln -sf lvm lvs )
( cd usr/sbin ; rm -rf lvscan )
( cd usr/sbin ; ln -sf lvm lvscan )
( cd usr/sbin ; rm -rf pvchange )
( cd usr/sbin ; ln -sf lvm pvchange )
( cd usr/sbin ; rm -rf pvresize )
( cd usr/sbin ; ln -sf lvm pvresize )
( cd usr/sbin ; rm -rf pvck )
( cd usr/sbin ; ln -sf lvm pvck )
( cd usr/sbin ; rm -rf pvcreate )
( cd usr/sbin ; ln -sf lvm pvcreate )
( cd usr/sbin ; rm -rf pvdisplay )
( cd usr/sbin ; ln -sf lvm pvdisplay )
( cd usr/sbin ; rm -rf pvmove )
( cd usr/sbin ; ln -sf lvm pvmove )
( cd usr/sbin ; rm -rf pvremove )
( cd usr/sbin ; ln -sf lvm pvremove )
( cd usr/sbin ; rm -rf pvs )
( cd usr/sbin ; ln -sf lvm pvs )
( cd usr/sbin ; rm -rf pvscan )
( cd usr/sbin ; ln -sf lvm pvscan )
( cd usr/sbin ; rm -rf vgcfgbackup )
( cd usr/sbin ; ln -sf lvm vgcfgbackup )
( cd usr/sbin ; rm -rf vgcfgrestore )
( cd usr/sbin ; ln -sf lvm vgcfgrestore )
( cd usr/sbin ; rm -rf vgchange )
( cd usr/sbin ; ln -sf lvm vgchange )
( cd usr/sbin ; rm -rf vgck )
( cd usr/sbin ; ln -sf lvm vgck )
( cd usr/sbin ; rm -rf vgconvert )
( cd usr/sbin ; ln -sf lvm vgconvert )
( cd usr/sbin ; rm -rf vgcreate )
( cd usr/sbin ; ln -sf lvm vgcreate )
( cd usr/sbin ; rm -rf vgdisplay )
( cd usr/sbin ; ln -sf lvm vgdisplay )
( cd usr/sbin ; rm -rf vgexport )
( cd usr/sbin ; ln -sf lvm vgexport )
( cd usr/sbin ; rm -rf vgextend )
( cd usr/sbin ; ln -sf lvm vgextend )
( cd usr/sbin ; rm -rf vgimport )
( cd usr/sbin ; ln -sf lvm vgimport )
( cd usr/sbin ; rm -rf vgmerge )
( cd usr/sbin ; ln -sf lvm vgmerge )
( cd usr/sbin ; rm -rf vgmknodes )
( cd usr/sbin ; ln -sf lvm vgmknodes )
( cd usr/sbin ; rm -rf vgreduce )
( cd usr/sbin ; ln -sf lvm vgreduce )
( cd usr/sbin ; rm -rf vgremove )
( cd usr/sbin ; ln -sf lvm vgremove )
( cd usr/sbin ; rm -rf vgrename )
( cd usr/sbin ; ln -sf lvm vgrename )
( cd usr/sbin ; rm -rf vgs )
( cd usr/sbin ; ln -sf lvm vgs )
( cd usr/sbin ; rm -rf vgscan )
( cd usr/sbin ; ln -sf lvm vgscan )
( cd usr/sbin ; rm -rf vgsplit )
( cd usr/sbin ; ln -sf lvm vgsplit )
( cd usr/lib ; rm -rf libdevmapper.so )
( cd usr/lib ; ln -sf libdevmapper.so.1.02 libdevmapper.so )

==> lvm2-2.02.72-i586-P1.tgz: install/doinst.sh <==
( cd usr/sbin ; rm -rf lvchange )
( cd usr/sbin ; ln -sf lvm lvchange )
( cd usr/sbin ; rm -rf lvconvert )
( cd usr/sbin ; ln -sf lvm lvconvert )
( cd usr/sbin ; rm -rf lvcreate )
( cd usr/sbin ; ln -sf lvm lvcreate )
( cd usr/sbin ; rm -rf lvdisplay )
( cd usr/sbin ; ln -sf lvm lvdisplay )
( cd usr/sbin ; rm -rf lvextend )
( cd usr/sbin ; ln -sf lvm lvextend )
( cd usr/sbin ; rm -rf lvmchange )
( cd usr/sbin ; ln -sf lvm lvmchange )
( cd usr/sbin ; rm -rf lvmdiskscan )
( cd usr/sbin ; ln -sf lvm lvmdiskscan )
( cd usr/sbin ; rm -rf lvmsadc )
( cd usr/sbin ; ln -sf lvm lvmsadc )
( cd usr/sbin ; rm -rf lvmsar )
( cd usr/sbin ; ln -sf lvm lvmsar )
( cd usr/sbin ; rm -rf lvreduce )
( cd usr/sbin ; ln -sf lvm lvreduce )
( cd usr/sbin ; rm -rf lvremove )
( cd usr/sbin ; ln -sf lvm lvremove )
( cd usr/sbin ; rm -rf lvrename )
( cd usr/sbin ; ln -sf lvm lvrename )
( cd usr/sbin ; rm -rf lvresize )
( cd usr/sbin ; ln -sf lvm lvresize )
( cd usr/sbin ; rm -rf lvs )
( cd usr/sbin ; ln -sf lvm lvs )
( cd usr/sbin ; rm -rf lvscan )
( cd usr/sbin ; ln -sf lvm lvscan )
( cd usr/sbin ; rm -rf pvchange )
( cd usr/sbin ; ln -sf lvm pvchange )
( cd usr/sbin ; rm -rf pvresize )
( cd usr/sbin ; ln -sf lvm pvresize )
( cd usr/sbin ; rm -rf pvck )
( cd usr/sbin ; ln -sf lvm pvck )
( cd usr/sbin ; rm -rf pvcreate )
( cd usr/sbin ; ln -sf lvm pvcreate )
( cd usr/sbin ; rm -rf pvdisplay )
( cd usr/sbin ; ln -sf lvm pvdisplay )
( cd usr/sbin ; rm -rf pvmove )
( cd usr/sbin ; ln -sf lvm pvmove )
( cd usr/sbin ; rm -rf pvremove )
( cd usr/sbin ; ln -sf lvm pvremove )
( cd usr/sbin ; rm -rf pvs )
( cd usr/sbin ; ln -sf lvm pvs )
( cd usr/sbin ; rm -rf pvscan )
( cd usr/sbin ; ln -sf lvm pvscan )
( cd usr/sbin ; rm -rf vgcfgbackup )
( cd usr/sbin ; ln -sf lvm vgcfgbackup )
( cd usr/sbin ; rm -rf vgcfgrestore )
( cd usr/sbin ; ln -sf lvm vgcfgrestore )
( cd usr/sbin ; rm -rf vgchange )
( cd usr/sbin ; ln -sf lvm vgchange )
( cd usr/sbin ; rm -rf vgck )
( cd usr/sbin ; ln -sf lvm vgck )
( cd usr/sbin ; rm -rf vgconvert )
( cd usr/sbin ; ln -sf lvm vgconvert )
( cd usr/sbin ; rm -rf vgcreate )
( cd usr/sbin ; ln -sf lvm vgcreate )
( cd usr/sbin ; rm -rf vgdisplay )
( cd usr/sbin ; ln -sf lvm vgdisplay )
( cd usr/sbin ; rm -rf vgexport )
( cd usr/sbin ; ln -sf lvm vgexport )
( cd usr/sbin ; rm -rf vgextend )
( cd usr/sbin ; ln -sf lvm vgextend )
( cd usr/sbin ; rm -rf vgimport )
( cd usr/sbin ; ln -sf lvm vgimport )
( cd usr/sbin ; rm -rf vgmerge )
( cd usr/sbin ; ln -sf lvm vgmerge )
( cd usr/sbin ; rm -rf vgmknodes )
( cd usr/sbin ; ln -sf lvm vgmknodes )
( cd usr/sbin ; rm -rf vgreduce )
( cd usr/sbin ; ln -sf lvm vgreduce )
( cd usr/sbin ; rm -rf vgremove )
( cd usr/sbin ; ln -sf lvm vgremove )
( cd usr/sbin ; rm -rf vgrename )
( cd usr/sbin ; ln -sf lvm vgrename )
( cd usr/sbin ; rm -rf vgs )
( cd usr/sbin ; ln -sf lvm vgs )
( cd usr/sbin ; rm -rf vgscan )
( cd usr/sbin ; ln -sf lvm vgscan )
( cd usr/sbin ; rm -rf vgsplit )
( cd usr/sbin ; ln -sf lvm vgsplit )
( cd usr/lib ; rm -rf libdevmapper.so )
( cd usr/lib ; ln -sf libdevmapper.so.1.02 libdevmapper.so )
#%% begin initialize lvm2-2.02.72-i586-P1
( cd /etc/lvm
  if [ ! -f lvm.conf ]; then
    mv lvm.conf.new lvm.conf
  fi
)
#%% end
